@@ -4,4 +4,6 @@ item *assoc_find(const char *key, const size_t nkey);
 int assoc_insert(item *item);
 void assoc_delete(const char *key, const size_t nkey);
 void do_assoc_move_next_bucket(void);
-uint32_t hash( const void *key, size_t length, const uint32_t initval);
+int start_assoc_maintenance_thread(void);
+void stop_assoc_maintenance_thread(void);
+
