@@ -100,10 +100,6 @@ void slabs_init(const size_t limit, const double factor, const bool prealloc) {
     int i = POWER_SMALLEST - 1;
     unsigned int size = sizeof(item) + settings.chunk_size;
 
-    /* Factor of 2.0 means use the default memcached behavior */
-    if (factor == 2.0 && size < 128)
-        size = 128;
-
     mem_limit = limit;
 
     if (prealloc) {
@@ -120,7 +116,7 @@ void slabs_init(const size_t limit, const double factor, const bool prealloc) {
 
     memset(slabclass, 0, sizeof(slabclass));
 
-    while (++i < POWER_LARGEST && size <= settings.item_size_max / 2) {
+    while (++i < POWER_LARGEST && size <= settings.item_size_max / factor) {
         /* Make sure items are always n-byte aligned */
         if (size % CHUNK_ALIGN_BYTES)
             size += CHUNK_ALIGN_BYTES - (size % CHUNK_ALIGN_BYTES);
@@ -313,11 +309,15 @@ bool get_stats(const char *stat_type, int nkey, ADD_STAT add_stats, void *c) {
     if (add_stats != NULL) {
         if (!stat_type) {
             /* prepare general statistics for the engine */
+            STATS_LOCK();
             APPEND_STAT("bytes", "%llu", (unsigned long long)stats.curr_bytes);
             APPEND_STAT("curr_items", "%u", stats.curr_items);
             APPEND_STAT("total_items", "%u", stats.total_items);
             APPEND_STAT("evictions", "%llu",
                         (unsigned long long)stats.evictions);
+            APPEND_STAT("reclaimed", "%llu",
+                        (unsigned long long)stats.reclaimed);
+            STATS_UNLOCK();
         } else if (nz_strcmp(nkey, stat_type, "items") == 0) {
             item_stats(add_stats, c);
         } else if (nz_strcmp(nkey, stat_type, "slabs") == 0) {
