@@ -1,4 +1,6 @@
 /* slabs memory allocation */
+#ifndef SLABS_H
+#define SLABS_H
 
 /** Init the subsystem. 1st argument is the limit on no. of bytes to allocate,
     0 if no limit. 2nd argument is the growth factor; each slab will use a chunk
@@ -17,17 +19,15 @@ void slabs_init(const size_t limit, const double factor, const bool prealloc);
 unsigned int slabs_clsid(const size_t size);
 
 /** Allocate object of given length. 0 on error */ /*@null@*/
-void *do_slabs_alloc(const size_t size, unsigned int id);
+void *slabs_alloc(const size_t size, unsigned int id);
 
 /** Free previously allocated object */
-void do_slabs_free(void *ptr, size_t size, unsigned int id);
+void slabs_free(void *ptr, size_t size, unsigned int id);
+
+/** Return a datum for stats in binary protocol */
+bool get_stats(const char *stat_type, int nkey, ADD_STAT add_stats, void *c);
 
 /** Fill buffer with stats */ /*@null@*/
-char* do_slabs_stats(int *buflen);
-
-/* Request some slab be moved between classes
-  1 = success
-   0 = fail
-   -1 = tried. busy. send again shortly. */
-int do_slabs_reassign(unsigned char srcid, unsigned char dstid);
+void slabs_stats(ADD_STAT add_stats, void *c);
 
+#endif
